/*=============================================================================
 GameOverControl.js
----------------------------------------------------------------------------
// ----------------------------------------------------------------------------
// Copyright (C)2020-21 wingly
// This software is released under the MIT License.
// http://opensource.org/licenses/mit-license.php
// ----------------------------------------------------------------------------
/*:
 * @target MZ
 * @plugindesc 全滅時ゲームオーバー制御プラグイン
 * @author wingly（改変元:ゆわか）
 *
 * @param noGmaeOverSwitchID
 * @desc 全滅してもゲームオーバーにならないようにするスイッチです。
 * @default 0
 * @type switch
 *
 * @help
 *=============================================================================
 * 特定のスイッチがONの時にパーティーが全滅しても
 * ゲームオーバー画面に移動しないようにするプラグインです。
 *
 * 全滅時にゲームオーバー画面に行かずにただマップに戻されるだけです。
 * 戦闘不能ステート解除などの処理はこちらのプラグインでは行いません。
 *
 * もとのプラグインの仕様で戦闘の処理の場合はそちらの方が優先されます。
 *
 * プラグインコマンドはありません。
 * パラメーターからスイッチを指定してください。(デフォルト0)
 *
 * なお使用する際には必ず以下のクレジット表記をお願いします。
 *
 * (C)2020-21 wingly
 * 
 * ※注意※
 * このプラグインは「ゆわか」氏の""NoGameover2.js""を改変したものです。
 * よってこのプラグインはMITライセンスとなります。
 * (ライセンスについて自分はあまりよく知りません。)
 *
 * さらにこのプラグインは全くの初心者が個人用に作成したものなので、
 * 僕自身がこのプラグインのバグを修正や機能追加を行うことはありません。
 *
 *・変更箇所
 * メニュー禁止や回復の処理を消去し、ただそのままマップ画面に戻されるだけに。
 * 全滅後スイッチONではなく、スイッチがONの間全滅しないという処理に変更
 *
 *=============================================================================
 * 
 */

(() => {
  "use strict";

//=============================================================================
// PluginManager
//=============================================================================

    const pluginName = "GameOverControl";
  const parameters = PluginManager.parameters(pluginName);
  const nGOID = Number(parameters['noGmaeOverSwitchID'] || 0);

//動作コード
//rpg_managers.jsより（戦闘で全滅した場合）
BattleManager.updateBattleEnd = function() {
    if (this.isBattleTest()) {
        AudioManager.stopBgm();
        SceneManager.exit();
    } else if (!this._escaped && $gameParty.isAllDead()) {
        if (this._canLose) {
            $gameParty.reviveBattleMembers();
            SceneManager.pop();
        } else {
            if ($gameSwitches.value(nGOID)) {
            SceneManager.pop();
            }else{
            SceneManager.goto(Scene_Gameover);
            }
        }
    } else {
        SceneManager.pop();
    }
    this._phase = "";
};

//rmmz_scenes.jsより（フィールドで全滅した場合）
Scene_Base.prototype.checkGameover = function() {
    if ($gameParty.isAllDead()) {
        if ($gameSwitches.value(nGOID)) {
        } else {
            SceneManager.goto(Scene_Gameover);
        }

    }
};

})();